@@ -29,10 +29,10 @@ protected Q_SLOTS:
 
 private:
     void expunge(const Akonadi::Collection &col);
-    Akonadi::AgentInstance::List agentInstances();
-    Akonadi::Collection trashCollectionFolder();
-    Akonadi::Collection collectionFromId(Akonadi::Collection::Id id) const;
-    bool folderIsTrash(const Akonadi::Collection &col);
+    [[nodiscard]] Akonadi::AgentInstance::List agentInstances();
+    [[nodiscard]] Akonadi::Collection trashCollectionFolder();
+    [[nodiscard]] Akonadi::Collection collectionFromId(Akonadi::Collection::Id id) const;
+    [[nodiscard]] bool folderIsTrash(const Akonadi::Collection &col);
 
     const QAbstractItemModel *const mModel;
     Akonadi::Collection::Id the_trashCollectionFolder;
